@@ -9,7 +9,7 @@ use Data::Dumper;
 use File::Spec;
 use Carp;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our $DIR     = File::Spec->catfile($ENV{HOME}, '.ppconfig');
 
 # path: $DIR/${namespace}.pl
@@ -17,7 +17,8 @@ our $DIR     = File::Spec->catfile($ENV{HOME}, '.ppconfig');
 sub config_get ($) {
     my $namespace = shift;
     my $path = path($namespace);
-    return (do $path or Carp::croak "$!: $path");
+    local $@;
+    return (do $path or Carp::croak "$!$@" ? "$!$@: $path" : "Can't find config: $path");
 }
 
 sub config_set ($$) {
